<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Bee_Fashion
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?> xmlns="http://www.w3.org/1999/html">
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<header class="dt-header">
	<div class="container">
		<div class="row">
			<div class="col-lg-12">
				<div class="dt-header-left">
					<div class="dt-logo">

						<?php if ( get_theme_mod( 'bee_fashion_logo', 0 ) != '' ) : ?>


							<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><img src="<?php echo esc_url( get_theme_mod( 'bee_fashion_logo' ) ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>"></a>
						<?php else : ?>

							<h1>
								<span class="dt-site-name">
									<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a>

									<?php $description = get_bloginfo( 'description', 'display' );
									if ( $description || is_customize_preview() ) : ?><span class="dt-site-desc"><p class="site-description"><?php echo $description; ?></p></span><?php endif; ?>

								</span>
							</h1>

						<?php endif ?>

					</div><!-- .dt-logo -->

					<nav class="dt-main-menu-wrap">
						<div class="dt-main-menu">

							<?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) ); ?>

						</div><!-- .dt-main-menu -->
					</nav>
				</div>

				<div class="dt-header-right">
					<div class="dt-top-search-bar">

						<?php if ( is_active_sidebar( 'dt-top-bar-search' ) ) : ?>

							<span class="dt-search-wrap transition5">

								<?php dynamic_sidebar( 'dt-top-bar-search' ); ?>

								<span class="dt-search-icon">
									<i class="fa fa-search transition35"></i>
								</span><!-- .dt-search-wrap -->
							</span><!-- .dt-search-wrap -->

						<?php endif; ?>

						<div class="dt-search-md-wrap transition35">

							<?php dynamic_sidebar( 'dt-top-bar-search' ); ?>

						</div><!-- .dt-search-md-wrap -->
					</div><!-- .dt-top-social -->
				</div>

				<div class="clearfix"
			</div>
		</div><!-- .row -->
	</div><!-- .container -->

	<?php $header_image = get_header_image();
	if ( ! empty( $header_image ) ) : ?>

		<div class="dt-header-image">
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home">
				<img src="<?php esc_url( header_image()); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="header image" />
			</a>
		</div><!-- .dt-header-image -->

	<?php endif; ?>
</header><!-- .dt-header -->

<?php if( ! is_front_page() ) : ?>
	<div class="dt-breadcrumbs">
		<div class="container">
			<div class="row">
				<div class="col-lg-12 col-md-12">
					<?php bee_fashion_breadcrumb(); ?>
				</div><!-- .col-lg-12 .col-md-12 -->
			</div><!-- .row-->
		</div><!-- .container-->
	</div><!-- .dt-breadcrumbs-->
<?php endif; ?>
































<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'bee-fashion' ); ?></a>

	<header id="masthead" class="site-header" role="banner">
		<div class="site-branding">
			<?php
			if ( is_front_page() && is_home() ) : ?>
				<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
			<?php else : ?>
				<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
			<?php
			endif;

			$description = get_bloginfo( 'description', 'display' );
			if ( $description || is_customize_preview() ) : ?>
				<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
			<?php
			endif; ?>
		</div><!-- .site-branding -->

		<nav id="site-navigation" class="main-navigation" role="navigation">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><?php esc_html_e( 'Primary Menu', 'bee-fashion' ); ?></button>
			<?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) ); ?>
		</nav><!-- #site-navigation -->
	</header><!-- #masthead -->

	<div id="content" class="site-content">
